<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="52"/>
        <source>XMP Plugin</source>
        <translation>Módulo XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="66"/>
        <source>Module Files</source>
        <translation>Archivos de Módulo</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="121"/>
        <source>About XMP Audio Plugin</source>
        <translation>Acerca del Módulo de Audio XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="122"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Módulo de Audio XMP de Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="124"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Compilado contra libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Configuración de Módulo XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation>Factor de amplificación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Mezclado estéreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Tipo de interpolador:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Efecto del filtro de paso bajo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Usar el tiempo vblank</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Emular error FX9 de Protracker 2.x</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Tasa de muestreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Vecino más cercano</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Ranura cúbica</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="49"/>
        <source>File name</source>
        <translation>Nombre del archivo</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Volume scale</source>
        <translation>Escala de volumen</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of patterns</source>
        <translation>Número de patrones</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of tracks</source>
        <translation>Número de pistas</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Tracks per pattern</source>
        <translation>Pistas por patrón</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Number of instruments</source>
        <translation>Número de instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Number of samples</source>
        <translation>Número de muestras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Initial speed</source>
        <translation>Velocidad inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="62"/>
        <source>Initial BPM</source>
        <translation>BPM inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="63"/>
        <source>Module length in patterns</source>
        <translation>Longitud del módulo en patrones</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="82"/>
        <source>Samples</source>
        <translation>Muestreo</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="90"/>
        <source>Instruments</source>
        <translation>Instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="95"/>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
</context>
</TS>
